import 'package:flutter/material.dart';
import 'fx_colors.dart';
import 'fx_text.dart';

class BottomDialog<T> extends StatefulWidget {
  final Function(T? result) onConfirm;
  final bool Function()? canConfirm;

  final T? Function()? getSelectedItem;

  final String title;
  final Widget body;

  const BottomDialog(
      {Key? key,
      required this.onConfirm,
      required this.title,
      required this.body,
      this.canConfirm,
      this.getSelectedItem})
      : super(key: key);

  @override
  _BottomDialogState createState() => _BottomDialogState<T>();
}

class _BottomDialogState<T> extends State<BottomDialog<T>> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 418,
      decoration: BoxDecoration(color: FXColor.main_white, borderRadius: BorderRadius.circular(12)),
      alignment: Alignment.topCenter,
      padding: const EdgeInsets.only(top: 12),
      child: Column(
        children: [
          GestureDetector(
            onTap: () => Navigator.of(context).pop(),
            child: Container(
                padding: const EdgeInsets.symmetric(horizontal: 16),
                alignment: Alignment.topRight,
                child: Image.asset('images/close.png', width: 16, height: 16)),
          ),
          Container(
            padding: const EdgeInsets.only(bottom: 20),
            child: FXText(widget.title, style: FXText.title_black),
          ),
          Expanded(
            child: widget.body,
          ),
          const SizedBox(height: 4),
          GestureDetector(
            onTap: () async {
              var result = await widget.onConfirm(widget.getSelectedItem?.call());
              if (result == null) {
                Navigator.of(context).pop();
                return;
              }
            },
            child: Container(
                margin: const EdgeInsets.symmetric(vertical: 16, horizontal: 12),
                width: double.infinity,
                alignment: Alignment.center,
                decoration: BoxDecoration(
                    color: FXColor.main_blue.withOpacity((widget.canConfirm?.call() ?? false) ? 1 : 0.5),
                    borderRadius: const BorderRadius.all(Radius.circular(10))),
                padding: const EdgeInsets.symmetric(vertical: 15),
                child: FXText('确定', style: FXText.title_white.apply(fontWeightDelta: -2))),
          )
        ],
      ),
    );
  }
}
