import 'package:flutter/services.dart';
import 'dart:math' as math;


class DecimalTextInputFormatter extends TextInputFormatter {
  DecimalTextInputFormatter({required this.decimalRange, this.integerRange = 10})
      : assert(decimalRange == null || decimalRange > 0);

  final int integerRange;
  final int decimalRange;

  @override
  TextEditingValue formatEditUpdate(
      TextEditingValue oldValue, // unused.
      TextEditingValue newValue,
      ) {
    TextSelection newSelection = newValue.selection;
    String truncated = newValue.text;

    if (decimalRange != null) {
      String value = newValue.text;


      List<String> splits = value.split(".");
      String integerStr = splits[0];
      String decimalStr = splits.length > 1? splits[1]: "";
      var illegalNum = value.isNotEmpty && double.tryParse(value) == null;

      if (illegalNum || (integerStr.length > integerRange) || (decimalStr.length > decimalRange)) {
        truncated = oldValue.text;
        newSelection = oldValue.selection;
      }

      return TextEditingValue(
        text: truncated,
        selection: newSelection,
        composing: TextRange.empty,
      );
    }
    return newValue;
  }
}
