import 'package:flutter/material.dart';

import 'fx_colors.dart';
import 'fx_text.dart';

class PopupSelectDialog extends Dialog {
  final List<String> list;
  final Function(int selctIndex)? onSelect;

  final double? left;
  final double? right;
  final double? top;
  final double? bottom;
  final Color? bgColor;
  const PopupSelectDialog({Key? key, required this.list, this.onSelect, this.left, this.right, this.top = 0, this.bottom, this.bgColor}) : super(key: key);

  @override // TODO: implement backgroundColor
  Color? get backgroundColor => bgColor ?? super.backgroundColor;
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Positioned(
          right: right,
          top: top,
          left: left,
          bottom: bottom,
          child: Container(
            padding: const EdgeInsets.fromLTRB(8, 13, 8, 6),
            decoration: const BoxDecoration(
                image: DecorationImage(
                    image: AssetImage('images/dropdown.9.png'), centerSlice: Rect.fromLTRB(17, 23, 18, 30))),
            child: Column(
              children: [
                ...list.map((item) => Column(
                      children: [
                        _buildDialogItem(context, item),
                        if (item != list.last)
                          const SizedBox(
                              width: 130, child: Divider(thickness: 0.5, height: 0, color: FXColor.main_black5)),
                      ],
                    ))
              ],
            ),
          ),
        )
      ],
    );
  }

  Widget _buildDialogItem(BuildContext context, String title) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () {
        Navigator.pop(context);
        onSelect?.call(list.indexOf(title));
      },
      child: Container(
          padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 25),
          child: FXText(title, style: FXText.content.apply(decoration: TextDecoration.none))),
    );
  }
}
