import 'package:flutter/material.dart';

import 'bottom_dialog.dart';
import 'fx_colors.dart';
import 'fx_text.dart';

class DatePicker extends StatefulWidget {
  final Null Function(DateTime? result) onConfirm;

  const DatePicker({Key? key, required this.onConfirm}) : super(key: key);

  @override
  _DatePickerState createState() => _DatePickerState();
}

class _DatePickerState extends State<DatePicker> {
  DateTime resultDate = DateTime.now();
  final GlobalKey<_DateSelectorState> _dateSelectorKey = GlobalKey();

  bool changeStart = true;

  @override
  Widget build(BuildContext context) {
    var dateSelector = DateSelector(
        key: _dateSelectorKey,
        onSelect: (dateTime) {
          setState(() {
            resultDate = dateTime;
          });
        });

    return BottomDialog<DateTime>(
        getSelectedItem: () {
          return resultDate;
        },
        onConfirm: widget.onConfirm,
        canConfirm: () {
          return true;
        },
        title: '请选择日期',
        body: Column(
          children: [dateSelector],
        ));
  }
}

class DateSelector extends StatefulWidget {
  final Function(DateTime dateTime)? onSelect;

  const DateSelector({Key? key, this.onSelect}) : super(key: key);

  @override
  _DateSelectorState createState() => _DateSelectorState();

  static _DateSelectorState? of(BuildContext context) {
    return context.findAncestorStateOfType<_DateSelectorState>();
  }
}

class _DateSelectorState extends State<DateSelector> {
  DateTime get date => DateTime(year, month, day);

  var year = DateTime.now().year;
  var month = DateTime.now().month;
  var day = DateTime.now().day;

  final _yearController = PageController(viewportFraction: 0.2, initialPage: DateTime.now().year - 2020);
  final _monthController = PageController(viewportFraction: 0.2, initialPage: DateTime.now().month - 1);
  final _dayController = PageController(viewportFraction: 0.2, initialPage: DateTime.now().day - 1);

  @override
  void dispose() {
    _yearController.dispose();
    _monthController.dispose();
    _dayController.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Stack(
        children: [
          Align(
              alignment: Alignment.center,
              child: Container(
                height: 48,
                decoration: BoxDecoration(
                    color: FXColor.main_blue.withOpacity(0.08),
                    border:
                        const Border(top: BorderSide(color: FXColor.main_blue), bottom: BorderSide(color: FXColor.main_blue))),
              )),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 24),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                Expanded(
                  child: PageView.builder(
                      itemCount: 20,
                      scrollDirection: Axis.vertical,
                      physics: const BouncingScrollPhysics(),
                      controller: _yearController,
                      onPageChanged: (index) {
                        setState(() {
                          year = index + 2020;
                          widget.onSelect?.call(date);
                        });
                      },
                      itemBuilder: (context, index) {
                        return Align(
                            alignment: Alignment.centerLeft,
                            child: Text('${index + 2020}年',
                                style: year - 2020 == index
                                    ? FXText.content
                                    : FXText.content.apply(color: FXColor.black)));
                      }),
                ),
                Expanded(
                  child: PageView.builder(
                      itemCount: 12,
                      scrollDirection: Axis.vertical,
                      physics: const BouncingScrollPhysics(),
                      controller: _monthController,
                      onPageChanged: (index) {
                        setState(() {
                          month = index + 1;
                          widget.onSelect?.call(date);
                        });
                      },
                      itemBuilder: (context, index) {
                        return Align(
                            child: Text('${index + 1}月',
                                style:
                                    month - 1 == index ? FXText.content : FXText.content.apply(color: FXColor.black)));
                      }),
                ),
                Expanded(
                  child: PageView.builder(
                      itemCount: DateUtils.getDaysInMonth(year, month),
                      scrollDirection: Axis.vertical,
                      physics: const BouncingScrollPhysics(),
                      controller: _dayController,
                      onPageChanged: (index) {
                        setState(() {
                          day = index + 1;
                          widget.onSelect?.call(date);
                        });
                      },
                      itemBuilder: (context, index) {
                        return Align(
                            alignment: Alignment.centerRight,
                            child: Text('${index + 1}日',
                                style: day - 1 == index ? FXText.content : FXText.content.apply(color: FXColor.black)));
                      }),
                ),
              ],
            ),
          )
        ],
      ),
    );
  }
}
