import 'package:flutter/cupertino.dart';

import 'fx_colors.dart';

/// 修正不同手机上leading和不居中的问题
class FXText extends StatelessWidget {
  final String data;
  final TextStyle style;
  final int? maxLines;
  final double textMaxWidth;
  final TextAlign? textAlign;

  static const content_org = TextStyle(color: FXColor.main_black1, fontWeight: FontWeight.normal, fontSize: 16);
  static const content = TextStyle(
      color: FXColor.main_black1,
      fontWeight: FontWeight.normal,
      fontSize: 16,
      height: 1.0,
      leadingDistribution: TextLeadingDistribution.even);

  static const rich_content = TextStyle(
      color: FXColor.main_black1,
      fontWeight: FontWeight.normal,
      fontSize: 16,
      height: 1.0,
      leadingDistribution: TextLeadingDistribution.even);
  static var input_hint = content.copyWith(letterSpacing: 0, color: FXColor.main_black3, height: 1.5);
  static var subtitle = content.apply(fontSizeDelta: -2);
  static var comment = subtitle.apply(color: FXColor.main_black3);
  static var title_black = content.copyWith(fontWeight: FontWeight.w600, fontSize: 18);
  static var title_white = title_black.apply(color: FXColor.main_white);

  static const _fontSize2HeightMap = {11: 19, 12: 20, 14: 22, 16: 24, 18: 26, 20: 28, 28: 36, 48: 56};

  static double? adjustedHeight(double? fontSize) {
    return (_fontSize2HeightMap[fontSize] ?? 24) / (fontSize ?? 16);
  }

  const FXText(this.data,
      {Key? key, this.style = content, this.maxLines, this.textMaxWidth = double.infinity, this.textAlign})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Text(data,
        overflow: maxLines != null ? TextOverflow.ellipsis : null,
        maxLines: maxLines,
        textAlign: textAlign,
        style: style,
        strutStyle: StrutStyle(
          fontSize: style.fontSize,
          fontWeight: style.fontWeight,
          height: adjustedHeight(style.fontSize),
          // leading: 0.1, //TODO:意义不明
          forceStrutHeight: true, // 关键属性 强制改为文字高度
        ));
  }
}
