import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';

import '../dev/native_model.dart';
import 'fx_dialog.dart';
import 'fx_text.dart';

class FxUtils {
  FxUtils._();

  static bool isSysToolbarEnable(BuildContext context){
    return MediaQuery.of(context).padding.top > 0;
  }

  static String toWeightString(int weight) => (weight / 1000).toStringAsFixed(2);

  static void showToast(String? text) {
    if (FxUtils.isTextEmpty(text)) return;
    var widget = Container(
        constraints: const BoxConstraints(minHeight: 36, minWidth: 172),
        decoration: BoxDecoration(borderRadius: BorderRadius.circular(2), color: Colors.black.withOpacity(0.6)),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 11, horizontal: 11),
          child: FXText(text!, textAlign: TextAlign.center, style: FXText.subtitle.apply(color: Colors.white)),
        ));
    showToastWidget(widget);
  }

  static bool isTextEmpty(String? text) {
    return (text == null) || text.isEmpty;
  }

  static void log(Object? object) {
    if (!kReleaseMode) {
      // print(object);

      if(object is String) {
        NativeModel.instance.log(object);
      }
    }
  }

  static void showCommonConfirmDialog(BuildContext context,
      {String? title,
        String? message,
        String? cancleStr,
        Function()? cancleFunc,
        String? confirmStr,
        Function()? confirmFunc,
        Widget? customContent}) {

    FxDialog.show(context, title: title, message: message, cancelStr: cancleStr, confirmStr: confirmStr, onCancel: cancleFunc, onConfirm: confirmFunc, customContent: customContent);
  }
  static void hideKeyboard(BuildContext context) {
    FocusScopeNode currentFocus = FocusScope.of(context);
    if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
      FocusManager.instance.primaryFocus?.unfocus();
    }
  }
}
